@@ -638,6 +638,11 @@ commands reverses the effect of this variable.  Requires Netscape version
   :type '(repeat (string :tag "Argument"))
   :group 'browse-url)
 
+(defcustom browse-url-mosaic-pidfile "~/.mosaicpid"
+  "The name of the pidfile created by Mosaic."
+  :type 'string
+  :group 'browse-url)
+
 (defcustom browse-url-filename-alist
   '(("^/\\(ftp@\\|anonymous@\\)?\\([^:]+\\):/*" . "ftp://\\2/")
     ;; The above loses the username to avoid the browser prompting for
@@ -1099,7 +1104,7 @@ the effect of `browse-url-new-window-p'.
 When called non-interactively, optional second argument NEW-WINDOW is
 used instead of `browse-url-new-window-p'."
   (interactive (browse-url-interactive-arg "Mosaic URL: "))
-  (let ((pidfile (expand-file-name "~/.mosaicpid"))
+  (let ((pidfile (expand-file-name browse-url-mosaic-pidfile))
 	pid)
     (if (file-readable-p pidfile)
 	(save-excursion
