@@ -573,8 +573,9 @@ This is relative to `smtpmail-queue-dir'.")
 (defun smtpmail-send-data-1 (process data)
   (goto-char (point-max))
 
-  (if (not (null smtpmail-code-conv-from))
-      (setq data (code-convert-string data smtpmail-code-conv-from *internal*)))
+  ;; XEmacs change
+  (if (and (featurep 'file-coding) (not (null smtpmail-code-conv-from)))
+      (setq data (encode-coding-string data smtpmail-code-conv-from)))
 	
   (if smtpmail-debug-info
       (insert data "\r\n"))
